@@ -1,6 +1,6 @@
 use v6;
 
-unit module TAP:ver<0.3.9>;
+unit module TAP:ver<0.3.10>;
 
 role Entry {
     has Str:D $.raw is required handles <Str>;
@@ -888,14 +888,18 @@ subset SourceHandler::Priority of Numeric where 0..1;
 
 role SourceHandler {
     method can-handle {...};
-    method make-source {...};
 
-    multi method make-parser(Str:D $name, Any:D :$err = 'stderr', IO:D(Str) :$cwd = $*CWD, Promise :$bailout, Bool :$loose, *%args) {
-        my $source = self.make-source($name, :$err, :$cwd, |%args);
-        $source.parse(:$bailout, :$loose);
+    proto method make-source(|) { * };
+    multi method make-source(IO:D $path, Any:D :$err, IO:D() :$cwd = $path.CWD, *%args) {
+        self.make-source($path.relative($cwd), :$cwd, |%args);
     }
-    multi method make-parser(IO:D $path, IO:D(Str) :$cwd = $path.CWD, *%args) {
-        self.make-parser($path.relative($cwd), :$cwd, |%args);
+    multi method make-source(::?CLASS:U: Str:D $name, *%args) {
+        self.new.make-source($name, |%args);
+    }
+
+    method make-parser(Any:D $name, Any:D :$err = 'stderr', Promise :$bailout, Bool :$loose, *%args) {
+        my $source = self.make-source($name, :$err, |%args);
+        $source.parse(:$bailout, :$loose);
     }
 }
 
@@ -906,7 +910,7 @@ my sub normalize-path($path, IO::Path $cwd) {
 class SourceHandler::Raku does SourceHandler {
     has Str:D $.path = $*EXECUTABLE.absolute;
     has @.incdirs;
-    method make-source(Str:D $name, Any:D :$err, IO::Path:D :$cwd, :@include-dirs = (), *%) {
+    multi method make-source(::?CLASS:D: Str:D $name, Any:D :$err = 'stderr', IO:D() :$cwd = $*CWD, :@include-dirs = (), *%) {
         my @dirs = flat @include-dirs, @!incdirs;
         my @args = |@dirs.map({ "-I" ~ normalize-path($^dir, $cwd) }), $name;
         TAP::Source::Proc.new(:$name, :$!path, :@args, :$err, :$cwd);
@@ -925,7 +929,7 @@ class SourceHandler::Exec does SourceHandler {
     method can-handle(Str $name) {
         $!priority;
     }
-    method make-source(Str:D $name, Any:D :$err, IO::Path:D :$cwd, *%) {
+    multi method make-source(::?CLASS:D: Str:D $name, Any:D :$err = 'stderr', IO:D() :$cwd = $*CWD, *%) {
         my $executable = ~$cwd.add($name);
         my ($path, *@args) = @!args ?? (|@!args, $executable) !! $executable;
         TAP::Source::Proc.new(:$name, :$path, :@args, :$err, :$cwd);
@@ -936,7 +940,7 @@ class SourceHandler::File does SourceHandler {
     method can-handle(Str $name) {
         $name ~~ /\.tap$/ ?? 1 !! 0;
     }
-    method make-source(Str:D $name, Any:D :$err, IO::Path:D :$cwd, *%) {
+    multi method make-source(::?CLASS:D: Str:D $name, IO:D() :$cwd = $*CWD, *%) {
         my $filename = $cwd.add($name);
         TAP::Source::File.new(:$name, :$filename);
     }
